@@ -5,6 +5,7 @@ We can then use a standard template and inject details from the
 specific transformation as we know the methods and properties available.
 """
 from abc import ABC, abstractmethod, abstractproperty
+from dataclasses import dataclass, field
 import os
 from typing import List, Optional
 
@@ -49,12 +50,13 @@ class IFileTransformer(ABC):
     @abstractproperty
     def accepts_file_extensions(self) -> List[str]:
         """ 
-        A list of valid unique file type specifiers as defined here:
-        https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/accept#unique_file_type_specifiers
-        Can be a MIME type e.g. 'image/*' or specific extension e.g. '.xlsx', '.xls', ...
+        A list of specific extensions supported e.g. ['.xlsx', '.xls', ...].
+        Note: the web service will return an error if you try to upload a file 
+        that is not in this list of extensions.
         """
         pass
 
+    # subclasses not *required* to override @property members, but can
     @property
     def target_file_ext(self) -> str:
         """
@@ -76,12 +78,22 @@ class IFileTransformer(ABC):
         """
         return None
 
+    @property
+    def tile_image_uri(self) -> Optional[str]:
+        """
+        Optional image uri to be displayed if services are listed as tiles.
+        """
+        return None
+
     def has_user_description_image(self) -> bool:
         return bool(self.user_description_image_uri)
 
-    def has_result_disclaimer_image_uri(self) -> bool:
+    def has_result_disclaimer_image(self) -> bool:
         return bool(self.result_disclaimer_image_uri)
 
+    def has_tile_image(self) -> bool:
+        return bool(self.tile_image_uri)
+
     def get_default_output_path(self, in_path, suffix: str='_transformed') -> str:
         directory, filename = os.path.split(in_path)
         output_filename = self.get_default_output_filename(filename, suffix)
@@ -92,5 +104,31 @@ class IFileTransformer(ABC):
         out_fname = f"{base_name}{suffix}{self.target_file_ext}"
         return out_fname
 
-    # TODO: Maybe - add accepts list of file extensions - could use in web app to pass
-    #       into form and limit the accepts control.
+
+@dataclass
+class ExtChecker:
+    """
+    Determines whether the ext of the filename (or path) is accepted.
+    the allow_zips arg allows you to return true for '.zip' even if not
+    in the accepted list. Use if you will check the unzipped file exts
+    are supported before processing.
+    """
+    transformer: IFileTransformer
+    file_name_or_path: str
+    allow_zips: bool
+    accept_exts: List[str] = field(init=False)
+    ext_is_valid: bool = field(init=False)
+    file_ext: str = field(init=False)
+
+    def __post_init__(self):
+        self.update_for_file()
+
+    def update_for_file(self, filename: str = None):
+        if filename:
+            self.file_name_or_path = filename
+        self.file_ext = os.path.splitext(self.file_name_or_path)[-1].lower()
+        self.accept_exts = [e.lower() for e in 
+                            self.transformer.accepts_file_extensions]
+        if self.allow_zips:
+            self.accept_exts = sorted(list(set(self.accept_exts + ['.zip'])))
+        self.ext_is_valid = self.file_ext in self.accept_exts
